@@ -1,7 +1,6 @@
 #' @author Samuel I. Berchuck \email{sib2@duke.edu}
 #'
 #' @name spCP
-#' @docType package
 #' @import Rcpp
 #' @importFrom stats quantile rnorm runif median
 #' @importFrom graphics abline axis layout par plot points polygon title segments symbols rect text lines
@@ -11,4 +10,4 @@
 #' @importFrom msm rtnorm
 #' @importFrom mvtnorm pmvnorm
 #' @useDynLib spCP
-NULL
+"_PACKAGE"
